@@ -1,18 +1,16 @@
 import os
 import sys
 
-from skimage import io, color
+from skimage import io
 from skimage.transform import resize
 from skimage.util import img_as_ubyte
 
 import torch
-from torchvision.transforms import transforms
 
 from PySide2.QtCore import Qt, QSize, QThread, Signal
 from PySide2.QtWidgets import (
     QApplication,
     QMainWindow,
-    QPushButton,
     QHBoxLayout,
     QLabel,
     QWidget,
@@ -20,8 +18,6 @@ from PySide2.QtWidgets import (
 )
 from PySide2.QtGui import QImage, QPixmap, QColor, QMovie
 
-import numpy as np
-
 from pva_resimagenet import ResImageNet
 
 class ImageProcessThread(QThread):
@@ -77,8 +73,6 @@ class MainWindow(QMainWindow):
         self.movie = QMovie(os.path.join(os.path.dirname(__file__), "data", "load_icon.gif"))
         self.movie.setScaledSize(QSize(200, 200))
 
-        self.button = QPushButton()
-
         layout.addWidget(self.image_in)
         layout.addWidget(self.image_out)
 
@@ -95,25 +89,9 @@ class MainWindow(QMainWindow):
             self.image_in.clear()
             self.image_out.clear()
 
-            tmp_array = io.imread(file_name)
-            w = tmp_array.shape[0]
-            w = (w // 4) * 4
-            h = tmp_array.shape[1]
-            h = (h // 4) * 4
-            if tmp_array.shape[0] != w and tmp_array.shape[1] != h:
-                tmp_array = resize(tmp_array, (w, h))
+            self.image_in_arr = io.imread(file_name)
 
-            # RGBA/RGB to Gray conversion
-            if len(tmp_array.shape) > 2:
-                if tmp_array.shape[2] > 3:
-                    tmp_array = color.rgba2rgb(tmp_array)
-                    tmp_array = color.rgb2gray(tmp_array)
-                elif tmp_array.shape[2] == 3:
-                    tmp_array = color.rgb2gray(tmp_array)
-
-            image_in = img_as_ubyte(tmp_array.copy())
-            tensor_transform = transforms.Compose([transforms.ToTensor()])
-            self.image_in_arr = tensor_transform(tmp_array)
+            image_in = img_as_ubyte(self.image_in_arr.copy())
 
             height, width = image_in.shape
             bytes_per_line = 1 * width
@@ -127,7 +105,7 @@ class MainWindow(QMainWindow):
             self.start_action.setDisabled(False)
 
     def processImage(self):
-        if self.image_in_arr != None:
+        if self.image_in_arr is not None:
             #Show load icon while waiting for end of process
             self.movie_label.setMovie(self.movie)
             self.movie.start()
